@@ -4,10 +4,8 @@ __author__ = "neutronics material maker development team"
 
 
 import os
-import json
 import re
 from json import JSONEncoder
-from pathlib import Path
 
 import warnings
 
@@ -151,7 +149,7 @@ class Material:
         enrichment_type=None,
         reference=None,
         zaid_suffix=None,
-        material_id=1,
+        material_id=None,
         volume_in_cm3=None,
     ):
 
@@ -567,7 +565,8 @@ class Material:
     def _make_openmc_material(self):
 
         original_cross_sections = os.environ.get('OPENMC_CROSS_SECTIONS')
-        del os.environ['OPENMC_CROSS_SECTIONS']
+        if original_cross_sections is not None:
+            del os.environ['OPENMC_CROSS_SECTIONS']
 
         if self.material_tag is None:
             name = self.material_name
@@ -593,7 +592,8 @@ class Material:
 
         openmc_material = self._add_density(openmc_material)
 
-        os.environ['OPENMC_CROSS_SECTIONS'] = original_cross_sections
+        if original_cross_sections is not None:
+            os.environ['OPENMC_CROSS_SECTIONS'] = original_cross_sections
 
         return openmc_material
 
