@@ -13,6 +13,20 @@ import neutronics_material_maker as nmm
 
 
 class test_object_properties(unittest.TestCase):
+
+    def test_iron_density(self):
+        a = nmm.Material("Iron")
+        assert a.openmc_material.density == 7.874
+        a = nmm.Material("Iron")
+        assert float(a.serpent_material.split('\n')[
+                     0].split()[2]) == pytest.approx(7.874)
+        a = nmm.Material("Iron", material_id=45)
+        assert float(a.mcnp_material.split('\n')[
+                     0].split()[3]) == pytest.approx(7.874)
+        a = nmm.Material("Iron", volume_in_cm3=100)
+        assert float(a.fispact_material.split('\n')[
+                     0].split()[1]) == pytest.approx(7.874)
+
     def test_fispact_material(self):
         a = nmm.Material("Li4SiO4", volume_in_cm3=1.0)
         line_by_line_material = a.fispact_material.split("\n")
@@ -444,7 +458,7 @@ class test_object_properties(unittest.TestCase):
 
             test_material.mcnp_material
 
-        self.assertRaises(ValueError, incorrect_setting_for_id)
+        self.assertRaises(ValueError, incorrect_setting_for_id2)
 
         def incorrect_setting_for_volume_in_cm3_1():
             """checks a ValueError is raised when the volume_in_cm3 is set to a string"""
@@ -459,7 +473,7 @@ class test_object_properties(unittest.TestCase):
 
             test_material.fispact_material
 
-        self.assertRaises(ValueError, incorrect_setting_for_id)
+        self.assertRaises(ValueError, incorrect_setting_for_volume_in_cm3_1)
 
         def incorrect_setting_for_volume_in_cm3_2():
             """checks a ValueError is raised when the id is not set and an mcnp material card is need"""
@@ -469,17 +483,17 @@ class test_object_properties(unittest.TestCase):
                 enrichment=50.0,
                 enrichment_target="Li6",
                 enrichment_type="ao",
-                volume_in_cm3="1",
+                material_id=None,
             )
 
             test_material.fispact_material
 
-        self.assertRaises(ValueError, incorrect_setting_for_id)
+        self.assertRaises(ValueError, incorrect_setting_for_volume_in_cm3_2)
 
     def test_setting_for_volume_int(self):
-        """checks a ValueError is raised when the volume_in_cm3 is set to an int"""
+        """checks the volume_in_cm3 is set to an int"""
 
-        test_material = nmm.Material(
+        nmm.Material(
             material_name="Li4SiO4",
             enrichment=50.0,
             enrichment_target="Li6",
@@ -487,12 +501,10 @@ class test_object_properties(unittest.TestCase):
             volume_in_cm3=1,
         )
 
-        test_material.fispact_material
-
     def test_setting_for_volume_float(self):
-        """checks a ValueError is raised when the volume_in_cm3 is set to an float"""
+        """checks the volume_in_cm3 is set to an float"""
 
-        test_material = nmm.Material(
+        nmm.Material(
             material_name="Li4SiO4",
             enrichment=50.0,
             enrichment_target="Li6",
@@ -500,8 +512,6 @@ class test_object_properties(unittest.TestCase):
             volume_in_cm3=1.1,
         )
 
-        test_material.fispact_material
-
     def test_json_dump_works(self):
         test_material = nmm.Material(
             "H2O", temperature_in_C=100, pressure_in_Pa=1e6)
